@@ -1,8 +1,8 @@
 use log::error;
-use regolith_displayd::{ DisplayManager, DisplayServer };
-use std::{ error::Error, future::pending, sync::Arc };
+use regolith_displayd::{DisplayManager, DisplayServer};
+use std::{error::Error, future::pending, sync::Arc};
 use swayipc_async::Connection as SwayConection;
-use tokio::{ sync::Mutex, try_join };
+use tokio::{sync::Mutex, try_join};
 
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn Error>> {
@@ -11,17 +11,17 @@ async fn main() -> Result<(), Box<dyn Error>> {
     let manager = DisplayManager::new().await;
     let manager_ref = Arc::new(Mutex::new(manager));
     let sway_connection = SwayConection::new().await.expect(
-        "Unable to connect to sway ipc interface. Make sure sway is running and SWAYSOCK is set"
+        "Unable to connect to sway ipc interface. Make sure sway is running and SWAYSOCK is set",
     );
     let sway_connection_ref = Arc::new(Mutex::new(sway_connection));
-    let server = DisplayServer::new(
-        Arc::clone(&manager_ref),
-        Arc::clone(&sway_connection_ref)
-    ).await;
+    let server =
+        DisplayServer::new(Arc::clone(&manager_ref), Arc::clone(&sway_connection_ref)).await;
     server.run_server().await.unwrap();
 
     let watch_handle = tokio::spawn(async move {
-        DisplayManager::watch_changes(manager_ref, sway_connection_ref).await.unwrap();
+        DisplayManager::watch_changes(manager_ref, sway_connection_ref)
+            .await
+            .unwrap();
     });
 
     if let Err(e) = try_join!(watch_handle) {
@@ -29,4 +29,5 @@ async fn main() -> Result<(), Box<dyn Error>> {
     }
     pending::<()>().await;
     Ok(())
-}
\ No newline at end of file
+}
+
